# FIT Connect .NET SDK User Guide

## Einleitung

Das FIT Connect .NET SDK bietet einen einfache Möglichkeit sowohl einen Antragsteller als auch einen
Antragsempfänger an FIT Connect anzubinden.

## Voraussetzungen

### Sender

Um einen Antrag mit dem SDK versenden zu können werden eine ClientID und ein ClientSecret benötigt.
Diese können beim Self Service Portal der FIT Connect angefordert werden.

[Offizelle Dokumentation der FIT Connect zum Einreichen](https://docs.fitko.de/fit-connect/docs/sending/overview)

### Subscriber

Der Subscriber benötigt sowohl eine ClientID und das ClientSecret aber auch die Schlüsselpaare zur
Verschlüsselung wie auch zum Signieren der Daten.
Die Schlüsselpaare können
mit [FIT Connect Tool ZIP](https://git.fitko.de/fit-connect/fit-connect-tools/-/archive/main/fit-connect-tools-main.zip)
oder hier ```git clone https://git.fitko.de/fit-connect/fit-connect-tools.git``` erstellt werden.

[Offizielle Dokumentation der FIT Connect zum Abrufen](https://docs.fitko.de/fit-connect/docs/receiving/overview)

# Beispiele

## Sender

```csharp
var submission = Client
    .GetSender(FitConnectEnvironment.Development, clientId, clientSecret, logger)
    .WithDestination(destinationId)
    .WithServiceType("FIT Connect Demo", leikaKey)
    .WithAttachments(new Attachment("Test.pdf", "Test Attachment"))
    .WithData("{\"message\":\"Hello World\"}")
    .Submit();
```

## Subscriber

### Erstellen des Subscribers

```csharp
var subscriber = Client.GetSubscriber(FitConnectEnvironment.Development, clientId,
    clientSecret,
    File.ReadAllText(privateKeyDecryption),
    File.ReadAllText(privateKeySigning),
    File.ReadAllText(publicKeyEncryption),
    File.ReadAllText(publicKeySignatureVerification),
    logger);
```

### Abrufen der Submissions

```csharp
var submissions = subscriber.GetAvailableSubmissions();
```

### Abrufen der Submissions mit den Anhängen

```csharp
foreach (var submission in submissions) {
    var subscriberWithAttachment = subscriber.RequestSubmission(submission.SubmissionId);
    var attachments = subscriberWithAttachment
        .GetAttachments();
    // Submission accept
    subscriberWithAttachment
        .AcceptSubmission();
    // or submission reject
   subscriberWithAttachment
        .RejectSubmission();

}
```
