using FitConnect.Models;
using FitConnect.Services.Interfaces;

namespace FitConnect.Interfaces.Sender;

public interface ISender {
    public string PublicKey { get; }

    /// <summary>
    ///     Determines the destination id and configures the sender.
    /// </summary>
    /// <param name="leiaKey"></param>
    /// <param name="ags"></param>
    /// <param name="ars"></param>
    /// <param name="areaId"></param>
    /// <returns></returns>
    public ISenderWithDestination FindDestinationId(string leiaKey, string? ags = null,
        string? ars = null,
        string? areaId = null);

    /// <summary>
    ///     Configures the client for the given destination and loads the public key
    /// </summary>
    /// <param name="destinationId">
    ///     unique identifier of the clients destination
    ///     <para>eg: 00000000-0000-0000-0000-000000000000</para>
    /// </param>
    /// <returns>the upload step for attachments</returns>
    public ISenderWithDestination WithDestination(string destinationId);


    /// <summary>
    /// Receives the SecurityEventTokens for a given case
    /// </summary>
    /// <param name="caseId">ID of the case</param>
    /// <returns>List of the <see cref="SecurityEventToken"/></returns>
    public List<SecurityEventToken> GetStatusForSubmission(string caseId);

    /// <summary>
    /// Finding areas for the filter with paging
    /// </summary>
    /// <param name="filter">Search string for the area, use * as wildcard</param>
    /// <param name="totalCount">out var for the total count</param>
    /// <param name="offset"></param>
    /// <param name="limit"></param>
    /// <example>
    /// var areas = GetAreas("Erlang*", out var _, 0, 10)
    /// </example>
    /// <returns></returns>
    public IEnumerable<Area> GetAreas(string filter, out int totalCount, int offset = 0,
        int limit = 100);
}
